# Doks

[![GitHub release](https://img.shields.io/github/release/h-enk/doks.svg?style=flat-square)](https://github.com/h-enk/doks/releases)
[![GitHub Workflow CI Status (master)](https://img.shields.io/github/workflow/status/h-enk/doks/CI/master?style=flat-square)](https://github.com/h-enk/doks/actions?query=workflow%3ACI)
[![Netlify](https://img.shields.io/netlify/895a161c-86be-48a2-8c57-a8c5d68cd1a4?style=flat-square)](https://doks.netlify.com/)

Doks is a Hugo theme helping you build modern documentation websites that are secure, fast, and SEO-ready — by default.

![Doks — Modern Documentation Theme](https://raw.githubusercontent.com/h-enk/doks/master/images/tn.png)

## Demo

- [doks.netlify.app](https://doks.netlify.app/)

## Quick start

Get your Doks site in 1 min.

[![Deploy to Netlify](https://www.netlify.com/img/deploy/button.svg)](https://app.netlify.com/start/deploy?repository=https://github.com/h-enk/doks)

## Why Doks?

Nine reasons why you should use Doks:

1. __Security aware__. Get A+ scores on [Mozilla Observatory](https://observatory.mozilla.org/analyze/doks.netlify.app) out of the box. Easily change the default Security Headers to suit your needs.

2. __Fast by default__. Get 100 scores on [Google Lighthouse](https://googlechrome.github.io/lighthouse/viewer/?gist=7731347bb8ce999eff7428a8e763b637) by default. Doks removes unused css, prefetches links, and lazy loads images.

3. __SEO-ready__. Use sensible defaults for structured data, open graph, and Twitter cards. Or easily change the SEO settings to your liking.

4. __Development tools__. Code with confidence. Check styles, scripts, and markdown for errors and fix automatically or manually.

5. __Bootstrap framework__. Build robust, flexible, and intuitive websites with Bootstrap. Or use any other front-end framework if you prefer.

6. __Netlify-ready__. Deploy to Netlify with sensible defaults. Easily use Netlify Functions, Netlify Redirects, and Netlify Headers.

7. __Full text search__. Search your Doks site with FlexSearch. Easily customize index settings and search options to your liking.

8. __Page layouts__. Build pages with a landing page, blog, or documentation layout. Add custom sections and components to suit your needs.

9. __Dark mode__. Switch to a low-light UI with the click of a button. Change colors with variables to match your branding.

## Requirements

Make sure all dependencies have been installed:

- [Hugo](https://gohugo.io/getting-started/installing/) >= 0.75.0/extended (needed for SCSS processing support)
- [Node.js](https://nodejs.org/) >= 14.15.0 (needed to install npm packages and run commands)

## Get started

Have your local Doks site in three steps:

### 1. Create new Doks project

```bash
git clone https://github.com/h-enk/doks.git my-doks-site
```

### 2. Install npm packages

```bash
npm install
```

### 3. Start local development server

```bash
npm run start
```

## Other commands

Doks comes with [commands](https://getdoks.org/docs/prologue/commands/) for common tasks.

## Documentation

- [Netlify](https://docs.netlify.com/)
- [Hugo](https://gohugo.io/documentation/)
- [Doks](https://getdoks.org/)

## Communities

- [Netlify Community](https://community.netlify.com/)
- [Hugo Forums](https://discourse.gohugo.io/)
- [Doks Discussions](https://github.com/h-enk/doks/discussions)

## Blog
<!--START_SECTION:feed-->
* [Meet Doks: modern documentation theme for Hugo](https:&#x2F;&#x2F;henkverlinde.com&#x2F;meet-doks-modern-documentation-theme-for-hugo&#x2F;)
* [Continuous Integration workflow for your Hyas project](https:&#x2F;&#x2F;henkverlinde.com&#x2F;continuous-integration-workflow-for-your-hyas-project&#x2F;)
* [Introducing Hyas: Hugo starter helping you build modern websites](https:&#x2F;&#x2F;henkverlinde.com&#x2F;introducing-hyas-hugo-starter-helping-you-build-modern-websites&#x2F;)
<!--END_SECTION:feed-->
